@@ -42,14 +42,15 @@ class AverageMeter:
 class Logger():
     loggers = {}
     def __init__(self, use_wandb=True, wandb_entity=None, wandb_project=None, wandb_name=None
-                 , wandb_watch=False, main_process=True, wandb_id=None
+                 , wandb_watch=False, main_process=True, wandb_id=None, wandb_dir='./'
                  , args=None, model=False
                  , save=True):
         self.use_wandb = use_wandb and main_process
 
         if self.use_wandb:
-            wandb.init(entity=wandb_entity, project=wandb_project, name=wandb_name, resume="allow",
-                       config=args, id = wandb_id)
+            wandb.init(entity=wandb_entity, project=wandb_project, name=wandb_name
+                       , resume="allow", id = wandb_id, dir=os.path.join(wandb_dir, 'wandb')
+                       , config=args)
 
             if args: args.wandb_id = wandb.config.id = wandb.run.id
             if wandb_watch and model: wandb.watch(model, log='all')
@@ -112,7 +113,7 @@ if __name__ == "__main__":
     samples, targets, imgs, label_names = dataset.getItems(data_num)
 
     logger = Logger(use_wandb=True, wandb_entity="joonmyung", wandb_project="test", wandb_name="AAPP",
-                    wandb_watch=False)
+                    wandb_watch=False, wandb_dir="./")
 
     logger.addLog({ "sample A": [0, 4],
                     "sample B": [0, 3],
